@@ -1,5 +1,6 @@
-#' Get parameter set.
+#' @title Get parameter set.
 #'
+#' @description
 #' Each smoof function contains a parameter set of type \code{\link[ParamHelpers]{ParamSet}}
 #' assigned to it, which describes types and bounds of the function parameters.
 #' This function returns the parameter set.
@@ -8,19 +9,18 @@
 #' @return [\code{\link[ParamHelpers]{ParamSet}}]
 #' @examples
 #' fn = makeSphereFunction(3L)
-#' ps = smoof::getParamSet(fn)
+#' ps = getParamSet(fn)
 #' print(ps)
+#' @name getParamSet
+#' @rdname getParamSet
+NULL
+
 #' @export
-getParamSet = function(fn) {
-  UseMethod("getParamSet")
+getParamSet.smoof_function = function(x) {
+  return(attr(x, "par.set"))
 }
 
 #' @export
-getParamSet.smoof_function = function(fn) {
-  return(attr(fn, "par.set"))
-}
-
-#' @export
-getParamSet.smoof_wrapped_function = function(fn) {
-  return(getParamSet(getWrappedFunction(fn)))
+getParamSet.smoof_wrapped_function = function(x) {
+  return(getParamSet(getWrappedFunction(x)))
 }
