@@ -12,7 +12,9 @@
 makeBealeFunction = function() {
   makeSingleObjectiveFunction(
     name = "Beale Function",
+    id = "beale_2d",
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       a = x[1] * x[2]
       b = a * x[2]
       c = b * x[2]
@@ -32,6 +34,6 @@ makeBealeFunction = function() {
 }
 
 class(makeBealeFunction) = c("function", "smoof_generator")
-attr(makeBealeFunction, "name") = c("Beale Function")
+attr(makeBealeFunction, "name") = c("Beale")
 attr(makeBealeFunction, "type") = c("single-objective")
-attr(makeBealeFunction, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "unimodal")
+attr(makeBealeFunction, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "unimodal")
